﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

# Note that many of these screens may be given additional arguments in the
# future. The use of **kwargs in the parameter list ensures your code will
# work in the future.

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say(who, what, side_image=None, two_window=False):

    # Decide if we want to use the one-window or two-window variant.
    if not two_window:

        # The one window variant.
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"
            
            window:
                ypos 311   
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"
                
            if who:
                window:
                    ypos -57 
                    style "say_who_window"

                    text who:
                        id "who"



    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Use the quick menu.
    use quick_menu


##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice(items):

    window:
        style "menu_window"
        xalign 0.5
        yalign 0.5

        vbox:
            style "menu"
            spacing 10

            for caption, action, chosen in items:

                if action:

                    button:
                        action action at buttonfade
                        style "menu_choice_button"

                        text caption style "menu_choice"

                else:
                    text caption style "menu_caption"

init -2:
    $ config.narrator_menu = True

    style menu_window is default

    style menu_choice is button_text:
        clear
        color "#40003f"
        size 20

    style menu_choice_button is button:
        xminimum 550
        xmaximum 550
        yminimum 63
        idle_background Frame("GUI/choice.png",0,0)
        hover_background Frame("GUI/choice_hover.png",0,0)
        xpadding 50
        top_padding 15
        bottom_padding 10


##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input(prompt):

    window style "input_window":
        has vbox

        text prompt style "input_prompt"
        input id "input" style "input_text"

    use quick_menu

##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl(dialogue, items=None):

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0

    use quick_menu

##############################################################################
# Main Menu
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu():

    # This ensures that any other menu screen is replaced.
    tag menu

    # The background of the main menu.
    window:
        style "mm_root"

    imagemap:
        alpha False
        ground "GUI/mm_base.png" 
        idle "GUI/idle.png"
        hover "GUI/mm_hover.png" 
        insensitive "GUI/idle.png"
            
        hotspot (892, 326, 177, 58) at buttonfade clicked Start()

        hotspot (892, 390, 177, 58) at buttonfade clicked ShowMenu("main_load")

        hotspot (892, 456, 177, 58) at buttonfade clicked ShowMenu("main_preferences")
 
        hotspot (892, 522, 177, 58) at buttonfade clicked ShowMenu("extras")

        hotspot (892, 586, 177, 58) at buttonfade clicked Quit(confirm=False)


init -2:

    # Make all the main menu buttons be the same size.
    style mm_button:
        size_group "mm"
        
    style say_dialogue:
        is default
        
        


##############################################################################
# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation():

    # The background of the game menu.
    window:
        style "gm_root"

    # The various buttons.
    frame:
        style_group "gm_nav"
        xalign .98
        yalign .98

        has vbox

        textbutton _("Return") action Return()
        textbutton _("Preferences") action ShowMenu("preferences")
        textbutton _("Save Game") action ShowMenu("save")
        textbutton _("Load Game") action ShowMenu("load")
        textbutton _("Main Menu") action MainMenu()
        textbutton _("Help") action Help()
        textbutton _("Quit") action Quit()

init -2:

    # Make all game menu navigation buttons the same size.
    style gm_nav_button:
        size_group "gm_nav"


##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.

screen load_save_slot:
    #tag menu
    #modal True
    $ file_text = "%2s. %s\n  %s" % (
                        FileSlotName(number, 6),
                        FileTime(number, empty=_("Empty slot")),
                        FileSaveName(number))

    add FileScreenshot(number) xpos 7 ypos 6 
    text file_text xalign .5 yalign 1.1 size 18 

screen save():

    # This ensures that any other menu screen is replaced.
    tag menu
    add "GUI/save_screen.png"
    
    imagemap:
        alpha False
        ground "GUI/slots.png" 
        idle "GUI/idle.png"
        hover "GUI/slots_hover.png" 
        insensitive "GUI/idle.png"
            
        hotspot (315, 197, 201, 123) at slotfade clicked FileAction(1):
            use load_save_slot(number=1)
        hotspot (536, 197, 201, 123) at slotfade clicked FileAction(2):
            use load_save_slot(number=2)
        hotspot (757, 197, 201, 123) at slotfade clicked FileAction(3):
            use load_save_slot(number=3)     
        hotspot (315, 347, 201, 123) at slotfade clicked FileAction(4):
            use load_save_slot(number=4)   
        hotspot (536, 347, 201, 123) at slotfade clicked FileAction(5):
            use load_save_slot(number=5)  
        hotspot (757, 347, 201, 123) at slotfade clicked FileAction(6):
            use load_save_slot(number=6)   
        
        
    hbox:
        xalign 0.5
        ypos 495
        spacing 0
        imagebutton idle "GUI/1.png" hover "GUI/1_hover.png" selected_idle "GUI/1_hover.png" focus_mask True clicked FilePage("1") at buttonfade
        imagebutton idle "GUI/2.png" hover "GUI/2_hover.png" selected_idle "GUI/2_hover.png" focus_mask True clicked FilePage("2") at buttonfade
        imagebutton idle "GUI/3.png" hover "GUI/3_hover.png" selected_idle "GUI/3_hover.png" focus_mask True clicked FilePage("3") at buttonfade
        imagebutton idle "GUI/4.png" hover "GUI/4_hover.png" selected_idle "GUI/4_hover.png" focus_mask True clicked FilePage("4") at buttonfade
        imagebutton idle "GUI/5.png" hover "GUI/5_hover.png" selected_idle "GUI/5_hover.png" focus_mask True clicked FilePage("5") at buttonfade
        
    hbox:
        xpos 907
        ypos 535
        imagebutton idle "GUI/return.png" hover "GUI/return_hover.png"  action Return() 

    hbox:
        xpos 293
        ypos 100
        imagebutton idle "GUI/load.png" hover "GUI/load_hover.png"  action ShowMenu("load") 

    hbox:
        xpos 380
        ypos 100
        imagebutton idle "GUI/options.png" hover "GUI/options_hover.png"  action ShowMenu("preferences") 

    hbox:
        xpos 775
        ypos 100
        imagebutton idle "GUI/main.png" hover "GUI/main_hover.png"  action MainMenu() 

    hbox:
        xpos 921
        ypos 100
        imagebutton idle "GUI/quit.png" hover "GUI/quit_hover.png"  action Quit()

screen load():

    # This ensures that any other menu screen is replaced.
    tag menu
    add "GUI/load_screen.png"
    
    imagemap:
        alpha False
        ground "GUI/slots.png" 
        idle "GUI/idle.png"
        hover "GUI/slots_hover.png" 
        insensitive "GUI/idle.png"
            
        hotspot (315, 197, 201, 123) at slotfade clicked FileAction(1):
            use load_save_slot(number=1)
        hotspot (536, 197, 201, 123) at slotfade clicked FileAction(2):
            use load_save_slot(number=2)
        hotspot (757, 197, 201, 123) at slotfade clicked FileAction(3):
            use load_save_slot(number=3)     
        hotspot (315, 347, 201, 123) at slotfade clicked FileAction(4):
            use load_save_slot(number=4)   
        hotspot (536, 347, 201, 123) at slotfade clicked FileAction(5):
            use load_save_slot(number=5)  
        hotspot (757, 347, 201, 123) at slotfade clicked FileAction(6):
            use load_save_slot(number=6)   
        
        
    hbox:
        xalign 0.5
        ypos 495
        spacing 0
        imagebutton idle "GUI/1.png" hover "GUI/1_hover.png" selected_idle "GUI/1_hover.png" focus_mask True clicked FilePage("1") at buttonfade
        imagebutton idle "GUI/2.png" hover "GUI/2_hover.png" selected_idle "GUI/2_hover.png" focus_mask True clicked FilePage("2") at buttonfade
        imagebutton idle "GUI/3.png" hover "GUI/3_hover.png" selected_idle "GUI/3_hover.png" focus_mask True clicked FilePage("3") at buttonfade
        imagebutton idle "GUI/4.png" hover "GUI/4_hover.png" selected_idle "GUI/4_hover.png" focus_mask True clicked FilePage("4") at buttonfade
        imagebutton idle "GUI/5.png" hover "GUI/5_hover.png" selected_idle "GUI/5_hover.png" focus_mask True clicked FilePage("5") at buttonfade
        
    hbox:
        xpos 907
        ypos 535
        imagebutton idle "GUI/return.png" hover "GUI/return_hover.png"  action Return() 

    hbox:
        xpos 293
        ypos 100
        imagebutton idle "GUI/save.png" hover "GUI/save_hover.png"  action ShowMenu("save") 

    hbox:
        xpos 380
        ypos 100
        imagebutton idle "GUI/options.png" hover "GUI/options_hover.png"  action ShowMenu("preferences") 

    hbox:
        xpos 775
        ypos 100
        imagebutton idle "GUI/main.png" hover "GUI/main_hover.png"  action MainMenu() 

    hbox:
        xpos 921
        ypos 100
        imagebutton idle "GUI/quit.png" hover "GUI/quit_hover.png"  action Quit()

screen main_load():

    # This ensures that any other menu screen is replaced.
    tag menu
    add "GUI/bg.jpg"
    add "GUI/load_screen.png"
    
    imagemap:
        alpha False
        ground "GUI/slots.png" 
        idle "GUI/idle.png"
        hover "GUI/slots_hover.png" 
        insensitive "GUI/idle.png"
            
        hotspot (315, 197, 201, 123) at slotfade clicked FileAction(1):
            use load_save_slot(number=1)
        hotspot (536, 197, 201, 123) at slotfade clicked FileAction(2):
            use load_save_slot(number=2)
        hotspot (757, 197, 201, 123) at slotfade clicked FileAction(3):
            use load_save_slot(number=3)     
        hotspot (315, 347, 201, 123) at slotfade clicked FileAction(4):
            use load_save_slot(number=4)   
        hotspot (536, 347, 201, 123) at slotfade clicked FileAction(5):
            use load_save_slot(number=5)  
        hotspot (757, 347, 201, 123) at slotfade clicked FileAction(6):
            use load_save_slot(number=6)   
        
        
    hbox:
        xalign 0.5
        ypos 495
        spacing 0
        imagebutton idle "GUI/1.png" hover "GUI/1_hover.png" selected_idle "GUI/1_hover.png" focus_mask True clicked FilePage("1") at buttonfade
        imagebutton idle "GUI/2.png" hover "GUI/2_hover.png" selected_idle "GUI/2_hover.png" focus_mask True clicked FilePage("2") at buttonfade
        imagebutton idle "GUI/3.png" hover "GUI/3_hover.png" selected_idle "GUI/3_hover.png" focus_mask True clicked FilePage("3") at buttonfade
        imagebutton idle "GUI/4.png" hover "GUI/4_hover.png" selected_idle "GUI/4_hover.png" focus_mask True clicked FilePage("4") at buttonfade
        imagebutton idle "GUI/5.png" hover "GUI/5_hover.png" selected_idle "GUI/5_hover.png" focus_mask True clicked FilePage("5") at buttonfade
        
    hbox:
        xpos 907
        ypos 535
        imagebutton idle "GUI/return.png" hover "GUI/return_hover.png"  action Return() 

    hbox:
        xpos 293
        ypos 100
        imagebutton idle "GUI/save.png" hover "GUI/save_hover.png"  action ShowMenu("save") 

    hbox:
        xpos 380
        ypos 100
        imagebutton idle "GUI/options.png" hover "GUI/options_hover.png"  action ShowMenu("main_preferences") 

    hbox:
        xpos 775
        ypos 100
        imagebutton idle "GUI/main.png" hover "GUI/main_hover.png"  action Return() 

    hbox:
        xpos 921
        ypos 100
        imagebutton idle "GUI/quit.png" hover "GUI/quit_hover.png"  action Quit()

init -2 python:
    config.thumbnail_width = 189
    config.thumbnail_height = 110
    config.quit_action = Quit(confirm=False)




##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces

screen preferences():

    tag menu

    # Include the navigation.
    add "GUI/options_screen.png"

    vbox:
        xpos 316
        ypos 213
        style_group "pref"
        textbutton _("Window") action Preference("display", "window") at buttonfade
        textbutton _("Fullscreen") action Preference("display", "fullscreen") at buttonfade

    vbox:
        xpos 316
        ypos 320
        style_group "pref"
        textbutton _("Seen Messages") action Preference("skip", "seen") at buttonfade
        textbutton _("All Messages") action Preference("skip", "all") at buttonfade

    vbox:
        xpos 316
        ypos 428
        style_group "pref"
        textbutton _("Stop Skipping") action Preference("after choices", "stop") at buttonfade
        textbutton _("Keep Skipping") action Preference("after choices", "skip") at buttonfade
        
    vbox:
        xpos 665
        ypos 214
        spacing 44
        style_group "pref"
        
        bar value Preference("text speed") 

        bar value Preference("auto-forward time") 

        bar value Preference("music volume") 

        bar value Preference("sound volume") 

        

    hbox:
        xpos 907
        ypos 535
        imagebutton idle "GUI/return.png" hover "GUI/return_hover.png"  action Return() 

    hbox:
        xpos 293
        ypos 100
        imagebutton idle "GUI/save.png" hover "GUI/save_hover.png"  action ShowMenu("save") 

    hbox:
        xpos 380
        ypos 100
        imagebutton idle "GUI/load.png" hover "GUI/load_hover.png"  action ShowMenu("load") 

    hbox:
        xpos 775
        ypos 100
        imagebutton idle "GUI/main.png" hover "GUI/main_hover.png"  action MainMenu() 

    hbox:
        xpos 921
        ypos 100
        imagebutton idle "GUI/quit.png" hover "GUI/quit_hover.png"  action Quit()
        
screen main_preferences():

    tag menu

    # Include the navigation.
    add "GUI/bg.jpg"
    add "GUI/options_screen.png"

    vbox:
        xpos 316
        ypos 213
        style_group "pref"
        textbutton _("Window") action Preference("display", "window") at buttonfade
        textbutton _("Fullscreen") action Preference("display", "fullscreen") at buttonfade

    vbox:
        xpos 316
        ypos 320
        style_group "pref"
        textbutton _("Seen Messages") action Preference("skip", "seen") at buttonfade
        textbutton _("All Messages") action Preference("skip", "all") at buttonfade

    vbox:
        xpos 316
        ypos 428
        style_group "pref"
        textbutton _("Stop Skipping") action Preference("after choices", "stop") at buttonfade
        textbutton _("Keep Skipping") action Preference("after choices", "skip") at buttonfade
        
    vbox:
        xpos 665
        ypos 214
        spacing 44
        style_group "pref"
        
        bar value Preference("text speed") 

        bar value Preference("auto-forward time") 

        bar value Preference("music volume") 

        bar value Preference("sound volume") 

        

    hbox:
        xpos 907
        ypos 535
        imagebutton idle "GUI/return.png" hover "GUI/return_hover.png"  action Return() 

    hbox:
        xpos 293
        ypos 100
        imagebutton idle "GUI/save.png" hover "GUI/save_hover.png"  action ShowMenu("save") 

    hbox:
        xpos 380
        ypos 100
        imagebutton idle "GUI/load.png" hover "GUI/load_hover.png"  action ShowMenu("main_load") 

    hbox:
        xpos 775
        ypos 100
        imagebutton idle "GUI/main.png" hover "GUI/main_hover.png"  action Return() 

    hbox:
        xpos 921
        ypos 100
        imagebutton idle "GUI/quit.png" hover "GUI/quit_hover.png"  action Quit()
                

init -2:
    style pref_vbox:
        xfill False
        xalign 0.0
        ypadding 0

    style pref_button:
        size_group "pref"
        xalign 0.0
        hover_background "GUI/button_hover.png"
        selected_idle_background "GUI/button_hover.png"
        idle_background "GUI/button.png"
        xsize 300
        ysize 33
        top_padding 1

    style pref_button_text:
        color "#40003f"

        
    style pref_slider:
        xmaximum 300
        xminimum 300
        ysize 33
        xalign 1.0
        thumb None
        left_bar "GUI/bar_full.png"
        right_bar "GUI/bar_empty.png"
        left_gutter 25
        right_gutter 25


##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt

screen yesno_prompt(message, yes_action, no_action):

    modal True

    add "GUI/yesno_screen.png"
    
    vbox:
        style_group "yesno"
        xalign .5
        yalign .35
        spacing 30

        label _(message):
            xalign 0.5

    hbox:
        xalign 0.5
        yalign 0.48
        spacing 10

        imagebutton idle "GUI/yes.png" hover "GUI/yes_hover.png" action yes_action 
        imagebutton idle "GUI/no.png" hover "GUI/no_hover.png" action no_action 
    # Right-click and escape answer "no".
    key "game_menu" action no_action

init -2:
    style yesno_button:
        size_group "yesno"

    style yesno_label_text:
        text_align 0.5
        layout "subtitle"

        size 24


##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu():

    # Add an in-game quick menu.
    hbox:
        style_group "quick"

        xalign 0.5
        yalign 0.99


        imagebutton idle "GUI/kauto.png" hover "GUI/kauto_hover.png" selected_idle "GUI/kauto_hover.png"  action Preference("auto-forward", "toggle") at buttonfade
        imagebutton idle "GUI/kskip.png" hover "GUI/kskip_hover.png" selected_idle "GUI/kskip_hover.png"  action Skip() at buttonfade        
        imagebutton idle "GUI/ksave.png" hover "GUI/ksave_hover.png" action ShowMenu('save') at buttonfade
        imagebutton idle "GUI/koptions.png" hover "GUI/koptions_hover.png" action ShowMenu('preferences') at buttonfade          
        imagebutton idle "GUI/kquit.png" hover "GUI/kquit_hover.png" action Quit() at buttonfade  

init -2:
    style quick_button:
        is default
        background None
        xpadding 5

    style quick_button_text:
        is default
        size 12
        idle_color "#8888"
        hover_color "#ccc"
        selected_idle_color "#cc08"
        selected_hover_color "#cc0"
        insensitive_color "#4448"

###########################################################################


screen extras():

    tag menu
    add "GUI/bg.jpg"    
    add "GUI/gallery_base.png"

    hbox:
        xalign 0.5
        ypos 495
        spacing 0
        imagebutton idle "GUI/1.png" hover "GUI/1_hover.png" selected_idle "GUI/1_hover.png" focus_mask True clicked [SetVariable('cg_page', 0), ShowMenu("extras")] at buttonfade
        imagebutton idle "GUI/2.png" hover "GUI/2_hover.png" selected_idle "GUI/2_hover.png" focus_mask True clicked [SetVariable('cg_page', 1), ShowMenu("extras")] at buttonfade
        imagebutton idle "GUI/3.png" hover "GUI/3_hover.png" selected_idle "GUI/3_hover.png" focus_mask True clicked [SetVariable('cg_page', 2), ShowMenu("extras")] at buttonfade
        imagebutton idle "GUI/4.png" hover "GUI/4_hover.png" selected_idle "GUI/4_hover.png" focus_mask True clicked [SetVariable('cg_page', 3), ShowMenu("extras")] at buttonfade
        
    hbox:
        xpos 293
        ypos 100
        imagebutton idle "GUI/credits.png" hover "GUI/credits_hover.png"  action ShowMenu("credits") 

    hbox:
        xpos 380
        ypos 100
        imagebutton idle "GUI/music.png" hover "GUI/music_hover.png"  action ShowMenu("music") 
        
    hbox:
        xpos 907
        ypos 535
        imagebutton idle "GUI/return.png" hover "GUI/return_hover.png"  action Return() 

    frame background None:
        grid 3 2:
            ypos 197
            xpos 315

            $ i = 0

            for gal_item in gallery_cgcommon_items:
                $ i += 1
                if i <= (cg_page+1)*gal_cells and i>cg_page*gal_cells:
                    add g_common.make_button(gal_item + " butt", gal_item + " butt", "GUI/locked.png", background=None, xpadding=0, top_padding=0, xmargin = 8, top_margin=0, bottom_margin=25)
            for j in range(i, (cg_page+1)*6): #we need this to fully fill the grid
                null

init python:
#    #Galleries settings - start

    gallery_cgcommon_items = ["cg_common_1", "cg_common_2", "cg_common_3", "cg_common_4", "cg_common_5", "cg_common_6", "cg_common_7", "cg_common_8", "cg_common_9", "cg_common_10", "cg_common_11", "cg_common_12", "cg_common_13", "cg_common_14", "cg_common_15", "cg_common_16", "cg_common_17", "cg_common_18", "cg_common_19", "cg_common_20", "cg_common_21", "cg_common_22"]
    thumbnail_x = 195
    thumbnail_y = 119
    gal_cells = 6 
    
    g_common = Gallery()
    for gal_item in gallery_cgcommon_items:
        g_common.button(gal_item + " butt")
        g_common.image(gal_item)
        g_common.unlock(gal_item)
    g_common.transition = fade
    cg_page=0
    g_common.hover_border = "GUI/frame.png"    
    g_common.idle_border = "GUI/frame_idle.png"

init +1 python:

    for gal_item in gallery_cgcommon_items:
        renpy.image (gal_item + " butt", im.Scale(ImageReference(gal_item), thumbnail_x, thumbnail_y))
        
screen credits():

    tag menu
    add "GUI/bg.jpg"
    add "GUI/credits_base.png"

    hbox:
        xpos 293
        ypos 100
        imagebutton idle "GUI/gallery.png" hover "GUI/gallery_hover.png"  action ShowMenu("extras") 

    hbox:
        xpos 380
        ypos 100
        imagebutton idle "GUI/music.png" hover "GUI/music_hover.png"  action ShowMenu("music") 
        
    hbox:
        xpos 907
        ypos 535
        imagebutton idle "GUI/return.png" hover "GUI/return_hover.png"  action Return() 
        
    hbox:
        xpos 228
        ypos 180
        imagebutton idle "tempcredits01.png"
        
init python:

    # Step 1. Create a MusicRoom instance.
    mr = MusicRoom(fadeout=1.0)

    # Step 2. Add music files.
    mr.add("music/aria.mp3", always_unlocked=True)
    mr.add("music/jungle.mp3", always_unlocked=True)
    mr.add("music/moonbathe.mp3", always_unlocked=True)
    mr.add("music/thehundredthtime.mp3", always_unlocked=True)
    
screen music():

    tag menu
    add "GUI/bg.jpg"    
    add "GUI/music_base.png"
    
    hbox:

        # The buttons that play each track.
        textbutton "Aria" action mr.Play("music/aria.mp3")
        textbutton "Jungle" action mr.Play("music/jungle.mp3")
        textbutton "Moonbathe" action mr.Play("music/moonbathe.mp3")
        textbutton "The Hundredth Time" action mr.Play("music/thehundredthtime.mp3")
        
        xpos 380
        ypos 250
        null height 20

    hbox:
        xpos 293
        ypos 100
        imagebutton idle "GUI/gallery.png" hover "GUI/gallery_hover.png"  action ShowMenu("extras") 

    hbox:
        xpos 380
        ypos 100
        imagebutton idle "GUI/credits.png" hover "GUI/credits_hover.png"  action ShowMenu("credits") 
        
    hbox:
        xpos 907
        ypos 535
        imagebutton idle "GUI/return.png" hover "GUI/return_hover.png"  action Return()               
        
